Bar code

US008188171B2

- c12)  United States Patent  Bernard et al.
- (IO)  Patent No.:  US 8,188,171 B2
- May 29, 2012  (45)  Date of Patent:
- (54)  POLYISOCYANATE COMPOSITION HAVING  IMPROVED IMPACT-PROOF PROPERTIES
- (75)  Inventors:  Jean-Marie Bernard,  Saint Laurent  d'  Agny (FR);  Mathias Dubecq,  Lyons  (FR)
- (73)  Assignee:  Rhodia Chimie,  Aubervilliers (FR)
- ( *)  Notice:  Subject to any disclaimer, the term ofthis  patent  is  extended  or adjusted  under  35  U.S.C. 154(b) by 992 days.
- (21)  Appl. No.:  11/793,489
- (22)  PCT Filed:  Dec. 20, 2005
- (86)  PCT No.:  PCT  /FR2005/003197
§ 371  (c)(l),
(2), (  4) Date:  Oct. 29, 2007
- (87)  PCT Pub. No.:  WO2006/067326
PCT Pub. Date:  Jun. 29, 2006
    - (65)  Prior Publication Data
- (30)  Foreign Application Priority Data
- (51)  Int. Cl.  C0SK 5100  (2006.01)
- (52)  U.S. Cl.  .....................  524/123;  427/385.5; 526/310;  528/44; 528/45; 528/68
- (58)  Field of Classification Search  ...................  524/123
    - (56)  References Cited
    ### U.S. PATENT DOCUMENTS
    ### FOREIGN PATENT DOCUMENTS
    Primary Examiner  - Doris Lee
- (74)  Attorney,  Agent,  or  Firm  - Buchanan  Ingersoll  &amp;  Rooney PC
    - (57)  ABSTRACT

See application file for complete search history.

The invention relates to the use of  additived (poly)isocyanate  compositions  for  producing  coatings,  especially  paints  or  varnishes for car bodywork parts, said compositions having  excellent impact-resistant properties, especially grit-resistant  properties.

36 Claims, No Drawings

<!-- missing-key-value-item -->